@@ -10,7 +10,7 @@ from .constants import DEFAULT_AUTH_TIMEOUT_S
 from .firetv.firetv_sync import FireTVSync
 
 
-__version__ = '0.0.56'
+__version__ = '0.0.59'
 
 
 def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, device_class='auto', auth_timeout_s=DEFAULT_AUTH_TIMEOUT_S, signer=None):
@@ -46,15 +46,15 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
     if device_class == 'androidtv':
         atv = AndroidTVSync(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, signer)
         atv.adb_connect(auth_timeout_s=auth_timeout_s)
-        atv.device_properties = atv.get_device_properties()
-        atv.installed_apps = atv.get_installed_apps()
+        atv.get_device_properties()
+        atv.get_installed_apps()
         return atv
 
     if device_class == 'firetv':
         ftv = FireTVSync(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, signer)
         ftv.adb_connect(auth_timeout_s=auth_timeout_s)
-        ftv.device_properties = ftv.get_device_properties()
-        ftv.installed_apps = ftv.get_installed_apps()
+        ftv.get_device_properties()
+        ftv.get_installed_apps()
         return ftv
 
     if device_class != 'auto':
@@ -69,7 +69,7 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
     aftv.device_properties = aftv.get_device_properties()
 
     # get the installed apps
-    aftv.installed_apps = aftv.get_installed_apps()
+    aftv.get_installed_apps()
 
     # Fire TV
     if aftv.device_properties.get('manufacturer') == 'Amazon':
@@ -79,6 +79,9 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
     else:
         aftv.__class__ = AndroidTVSync
 
+    # Fill in commands that are specific to the device
+    aftv._fill_in_commands()  # pylint: disable=protected-access
+
     return aftv
 
 
