@@ -37,6 +37,25 @@ class BaseAndroidTV(BaseTV):  # pylint: disable=too-few-public-methods
     def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None):
         BaseTV.__init__(self, None, host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
 
+    def _fill_in_commands(self):
+        """Fill in commands that are specific to Android TV devices."""
+        # Is this a Google Chromecast Android TV?
+        if "Google" in self.device_properties.get("manufacturer", "") and "Chromecast" in self.device_properties.get("model", ""):
+            self._cmd_get_properties_lazy_running_apps = constants.CMD_GOOGLE_TV_PROPERTIES_LAZY_RUNNING_APPS
+            self._cmd_get_properties_lazy_no_running_apps = constants.CMD_GOOGLE_TV_PROPERTIES_LAZY_NO_RUNNING_APPS
+            self._cmd_get_properties_not_lazy_running_apps = constants.CMD_GOOGLE_TV_PROPERTIES_NOT_LAZY_RUNNING_APPS
+            self._cmd_get_properties_not_lazy_no_running_apps = constants.CMD_GOOGLE_TV_PROPERTIES_NOT_LAZY_NO_RUNNING_APPS
+            self._cmd_current_app = constants.CMD_CURRENT_APP_GOOGLE_TV
+            self._cmd_launch_app = constants.CMD_LAUNCH_APP_GOOGLE_TV
+            return
+
+        self._cmd_get_properties_lazy_running_apps = constants.CMD_ANDROIDTV_PROPERTIES_LAZY_RUNNING_APPS
+        self._cmd_get_properties_lazy_no_running_apps = constants.CMD_ANDROIDTV_PROPERTIES_LAZY_NO_RUNNING_APPS
+        self._cmd_get_properties_not_lazy_running_apps = constants.CMD_ANDROIDTV_PROPERTIES_NOT_LAZY_RUNNING_APPS
+        self._cmd_get_properties_not_lazy_no_running_apps = constants.CMD_ANDROIDTV_PROPERTIES_NOT_LAZY_NO_RUNNING_APPS
+        self._cmd_current_app = constants.CMD_CURRENT_APP
+        self._cmd_launch_app = constants.CMD_LAUNCH_APP
+
     # ======================================================================= #
     #                                                                         #
     #                          Home Assistant Update                          #
