@@ -76,7 +76,14 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         self._state_detection_rules = state_detection_rules
         self.device_properties = {}
         self.installed_apps = []
-        self._is_google_tv = False
+
+        # commands that can vary based on the device
+        self._cmd_get_properties_lazy_running_apps = ""
+        self._cmd_get_properties_lazy_no_running_apps = ""
+        self._cmd_get_properties_not_lazy_running_apps = ""
+        self._cmd_get_properties_not_lazy_no_running_apps = ""
+        self._cmd_current_app = ""
+        self._cmd_launch_app = ""
 
         # make sure the rules are valid
         if self._state_detection_rules:
@@ -88,6 +95,13 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         # the max volume level (determined when first getting the volume level)
         self.max_volume = None
 
+    def _fill_in_commands(self):
+        """Fill in commands that are specific to the device.
+
+        This is implemented in the `BaseAndroidTV` and `BaseFireTV` classes.
+
+        """
+
     # ======================================================================= #
     #                                                                         #
     #                               ADB methods                               #
@@ -105,6 +119,23 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         """
         return self._adb.available
 
+    @staticmethod
+    def _remove_adb_shell_prefix(cmd):
+        """Remove the 'adb shell ' prefix from ``cmd``, if present.
+
+        Parameters
+        ----------
+        cmd : str
+            The ADB shell command
+
+        Returns
+        -------
+        str
+            ``cmd`` with the 'adb shell ' prefix removed, if it was present
+
+        """
+        return cmd[len("adb shell "):] if cmd.startswith("adb shell ") else cmd
+
     # ======================================================================= #
     #                                                                         #
     #                        Home Assistant device info                       #
@@ -118,27 +149,23 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         properties : str, None
             The output of the ADB command that retrieves the device properties
 
-        Returns
-        -------
-        dict
-            A dictionary with keys ``'wifimac'``, ``'ethmac'``, ``'serialno'``, ``'manufacturer'``, ``'model'``, and ``'sw_version'``
+        This method fills in the ``device_properties`` attribute, which is a dictionary with keys
+        ``'wifimac'``, ``'ethmac'``, ``'serialno'``, ``'manufacturer'``, ``'model'``, and ``'sw_version'``
 
         """
         _LOGGER.debug("%s:%d `get_device_properties` response: %s", self.host, self.port, properties)
 
         if not properties:
-            return {}
+            self.device_properties = {}
+            return
 
         lines = properties.strip().splitlines()
         if len(lines) != 6:
-            return {}
+            self.device_properties = {}
+            return
 
         manufacturer, model, serialno, version, mac_wlan0_output, mac_eth0_output = lines
 
-        # Is this a Google Chromecast Android TV?
-        if "Google" in manufacturer and "Chromecast" in model:
-            self._is_google_tv = True
-
         if not serialno.strip():
             _LOGGER.warning("Could not obtain serialno for %s:%d, got: '%s'", self.host, self.port, serialno)
             serialno = None
@@ -155,12 +182,14 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         else:
             ethmac = None
 
-        return {'manufacturer': manufacturer,
-                'model': model,
-                'serialno': serialno,
-                'sw_version': version,
-                'wifimac': wifimac,
-                'ethmac': ethmac}
+        self.device_properties = {'manufacturer': manufacturer,
+                                  'model': model,
+                                  'serialno': serialno,
+                                  'sw_version': version,
+                                  'wifimac': wifimac,
+                                  'ethmac': ethmac}
+
+        self._fill_in_commands()
 
     # ======================================================================= #
     #                                                                         #
@@ -378,7 +407,7 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         return hdmi_response.strip() if hdmi_response and hdmi_response.strip() else None
 
     @staticmethod
-    def _installed_apps(installed_apps_response):
+    def _get_installed_apps(installed_apps_response):
         """Get the installed apps from the output of :py:const:`androidtv.constants.CMD_INSTALLED_APPS`.
 
         Parameters
