@@ -100,7 +100,7 @@ class BaseTVAsync(BaseTV):
             The response from the device, if there is a response
 
         """
-        return await self._adb.shell(cmd)
+        return await self._adb.shell(self._remove_adb_shell_prefix(cmd))
 
     async def adb_pull(self, local_path, device_path):
         """Pull a file from the device.
@@ -198,7 +198,8 @@ class BaseTVAsync(BaseTV):
                                            constants.CMD_MAC_WLAN0 + " && " +
                                            constants.CMD_MAC_ETH0)
 
-        return self._parse_device_properties(properties)
+        self._parse_device_properties(properties)
+        return self.device_properties
 
     # ======================================================================= #
     #                                                                         #
@@ -250,7 +251,7 @@ class BaseTVAsync(BaseTV):
             The ID of the current app, or ``None`` if it could not be determined
 
         """
-        current_app_response = await self._adb.shell(constants.CMD_CURRENT_APP)
+        current_app_response = await self._adb.shell(self._cmd_current_app)
 
         return self._current_app(current_app_response)
 
@@ -275,7 +276,8 @@ class BaseTVAsync(BaseTV):
 
         """
         installed_apps_response = await self._adb.shell(constants.CMD_INSTALLED_APPS)
-        return self._installed_apps(installed_apps_response)
+        self.installed_apps = self._get_installed_apps(installed_apps_response)
+        return self.installed_apps
 
     async def is_volume_muted(self):
         """Whether or not the volume is muted.
@@ -426,7 +428,7 @@ class BaseTVAsync(BaseTV):
             The ID of the app that will be launched
 
         """
-        await self._adb.shell(constants.CMD_LAUNCH_APP.format(app) if not self._is_google_tv else constants.CMD_LAUNCH_APP_GOOGLE_TV.format(app))
+        await self._adb.shell(self._cmd_launch_app.format(app))
 
     async def stop_app(self, app):
         """Stop an app.
