@@ -28,20 +28,32 @@ CMD_AUDIO_STATE = r"dumpsys audio | grep paused | grep -qv 'Buffer Queue' && ech
 #: Determine whether the device is awake
 CMD_AWAKE = "dumpsys power | grep mWakefulness | grep -q Awake"
 
-#: Get the current app
-CMD_CURRENT_APP = "CURRENT_APP=$(dumpsys window windows | grep mCurrentFocus) && CURRENT_APP=${CURRENT_APP#*{* * } && CURRENT_APP=${CURRENT_APP%%/*} && echo $CURRENT_APP"
+#: Parse current application identifier from dumpsys output and assign it to ``CURRENT_APP`` variable (assumes dumpsys output is momentarily set to ``CURRENT_APP`` variable)
+CMD_PARSE_CURRENT_APP = 'CURRENT_APP=${CURRENT_APP#*ActivityRecord{* * } && CURRENT_APP=${CURRENT_APP#*{* * } && CURRENT_APP=${CURRENT_APP%%/*} && CURRENT_APP=${CURRENT_APP%\\}*}'
 
-#: Get the current app for a Google TV device
-CMD_CURRENT_APP_GOOGLE_TV = "CURRENT_APP=$(dumpsys activity a . | grep -E 'mResumedActivity' | cut -d ' ' -f 8) && CURRENT_APP=${CURRENT_APP%%/*} && echo $CURRENT_APP"
+#: Assign focused application identifier to ``CURRENT_APP`` variable
+CMD_DEFINE_CURRENT_APP_VARIABLE = "CURRENT_APP=$(dumpsys window windows | grep -E 'mCurrentFocus|mFocusedApp') && " + CMD_PARSE_CURRENT_APP
+
+#: Output identifier for current/focused application
+CMD_CURRENT_APP = CMD_DEFINE_CURRENT_APP_VARIABLE + ' && echo $CURRENT_APP'
+
+#: Assign focused application identifier to ``CURRENT_APP`` variable (for a Google TV device)
+CMD_DEFINE_CURRENT_APP_VARIABLE_GOOGLE_TV = 'CURRENT_APP=$(dumpsys activity a . | grep mResumedActivity) && ' + CMD_PARSE_CURRENT_APP
+
+#: Output identifier for current/focused application (for a Google TV device)
+CMD_CURRENT_APP_GOOGLE_TV = CMD_DEFINE_CURRENT_APP_VARIABLE_GOOGLE_TV + ' && echo $CURRENT_APP'
 
 #: Get the HDMI input
-CMD_HDMI_INPUT = "dumpsys activity starter | grep -o 'HDMIInputService\\/HW[0-9]' -m 1 | grep -o 'HW[0-9]'"
+CMD_HDMI_INPUT = "dumpsys activity starter | grep -E -o '(ExternalTv|HDMI)InputService/HW[0-9]' -m 1 | grep -o 'HW[0-9]'"
+
+#: Launch an app if it is not already the current app (assumes the variable ``CURRENT_APP`` has already been set)
+CMD_LAUNCH_APP_CONDITION = "if [ $CURRENT_APP != '{0}' ]; then monkey -p {0} -c " + INTENT_LAUNCH + " --pct-syskeys 0 1; fi"
 
 #: Launch an app if it is not already the current app
-CMD_LAUNCH_APP = "CURRENT_APP=$(dumpsys window windows | grep mCurrentFocus) && CURRENT_APP=${{CURRENT_APP#*{{* * }} && CURRENT_APP=${{CURRENT_APP%%/*}} && if [ $CURRENT_APP != '{0}' ]; then monkey -p {0} -c " + INTENT_LAUNCH + " --pct-syskeys 0 1; fi"
+CMD_LAUNCH_APP = CMD_DEFINE_CURRENT_APP_VARIABLE.replace('{', '{{').replace('}', '}}') + ' && ' + CMD_LAUNCH_APP_CONDITION
 
-#: Launch an app if it is not already the current app (for Google TV devices)
-CMD_LAUNCH_APP_GOOGLE_TV = "CURRENT_APP=$(dumpsys activity a . | grep -E 'mResumedActivity' | cut -d ' ' -f 8) && CURRENT_APP=${{CURRENT_APP%%/*}} && if [ $CURRENT_APP != '{0}' ]; then monkey -p {0} -c " + INTENT_LAUNCH + " --pct-syskeys 0 1; fi"
+#: Launch an app on a Google TV device
+CMD_LAUNCH_APP_GOOGLE_TV = CMD_DEFINE_CURRENT_APP_VARIABLE_GOOGLE_TV.replace('{', '{{').replace('}', '}}') + ' && ' + CMD_LAUNCH_APP_CONDITION
 
 #: Get the state from ``dumpsys media_session``; this assumes that the variable ``CURRENT_APP`` has been defined
 CMD_MEDIA_SESSION_STATE = "dumpsys media_session | grep -A 100 'Sessions Stack' | grep -A 100 $CURRENT_APP | grep -m 1 'state=PlaybackState {'"
@@ -293,14 +305,20 @@ MEDIA_SESSION_STATES = {0: None,
 
 # Apps
 APP_AE_TV = 'com.aetn.aetv.watch'
+APP_AMAZON_PRIME_VIDEO = 'com.amazon.avod.thirdpartyclient'
 APP_AMAZON_VIDEO = 'com.amazon.avod'
-APP_AMZ_VIDEO = 'com.amazon.avod.thirdpartyclient'
-APP_APPLE_TV = 'com.apple.atve.amazon.appletv'
+APP_APPLE_TV = 'com.apple.atve.sony.appletv'
+APP_APPLE_TV_FIRETV = 'com.apple.atve.amazon.appletv'
 APP_ATV_LAUNCHER = 'com.google.android.tvlauncher'
 APP_BELL_FIBE = 'com.quickplay.android.bellmediaplayer'
 APP_COMEDY_CENTRAL = 'com.vmn.android.comedycentral'
+APP_DAILYMOTION = 'com.dailymotion.dailymotion'
+APP_DEEZER = 'deezer.android.tv'
 APP_DISNEY_PLUS = 'com.disney.disneyplus'
+APP_DS_PHOTO = 'com.synology.dsphoto'
+APP_DS_VIDEO = 'com.synology.dsvideo'
 APP_ES_FILE_EXPLORER = 'com.estrongs.android.pop'
+APP_FACEBOOK = 'com.facebook.katana'
 APP_FAWESOME = 'com.future.moviesByFawesomeAndroidTV'
 APP_FIREFOX = 'org.mozilla.tv.firefox'
 APP_FIRETV_PACKAGE_LAUNCHER = 'com.amazon.tv.launcher'
@@ -309,15 +327,24 @@ APP_FIRETV_STORE = 'com.amazon.venezia'
 APP_FOOD_NETWORK_GO = 'tv.accedo.foodnetwork'
 APP_FRANCE_TV = 'fr.francetv.pluzz'
 APP_GOOGLE_CAST = 'com.google.android.apps.mediashell'
+APP_GOOGLE_TV_LAUNCHER = 'com.google.android.apps.tv.launcherx'
+APP_HAYSTACK_NEWS = 'com.haystack.android'
 APP_HBO_GO = 'eu.hbogo.androidtv.production'
 APP_HBO_GO_2 = 'com.HBO'
 APP_HULU = 'com.hulu.plus'
 APP_IMDB_TV = 'com.amazon.imdb.tv.android.app'
+APP_IPTV = 'ru.iptvremote.android.iptv'
 APP_IPTV_SMARTERS_PRO = 'com.nst.iptvsmarterstvbox'
 APP_JELLYFIN_TV = 'org.jellyfin.androidtv'
 APP_KODI = 'org.xbmc.kodi'
+APP_LIVE_CHANNELS = 'com.google.android.tv'
+APP_MIJN_RADIO = 'org.samsonsen.nederlandse.radio.holland.nl'
 APP_MOLOTOV = 'tv.molotov.app'
+APP_MX_PLAYER = 'com.mxtech.videoplayer.ad'
 APP_NETFLIX = 'com.netflix.ninja'
+APP_NLZIET = 'nl.nlziet'
+APP_NOS = 'nl.nos.app'
+APP_NPO = 'nl.uitzendinggemist'
 APP_OCS = 'com.orange.ocsgo'
 APP_PLAY_GAMES = 'com.google.android.games'
 APP_PLAY_MUSIC = 'com.google.android.music'
@@ -325,70 +352,133 @@ APP_PLAY_STORE = 'com.android.vending'
 APP_PLAY_VIDEOS = 'com.android.videos'
 APP_PLEX = 'com.plexapp.android'
 APP_PRIME_VIDEO = 'com.amazon.amazonvideo.livingroom'
-APP_PRIME_VIDEO_2 = 'com.amazon.firebat'
+APP_PRIME_VIDEO_FIRETV = 'com.amazon.firebat'
+APP_SETTINGS = 'com.android.tv.settings'
 APP_SMART_YOUTUBE_TV = 'com.liskovsoft.videomanager'
+APP_SONY_ACTION_MENU = 'com.sony.dtv.scrums.action'
+APP_SONY_ALBUM = 'com.sony.dtv.osat.album'
+APP_SONY_BRAVIA_SYNC_MENU = 'com.sony.dtv.braviasyncmenu'
+APP_SONY_BRAVIA_TUTORIALS = 'com.sony.dtv.bravialifehack'
+APP_SONY_DISCOVER = 'com.sony.dtv.discovery'
+APP_SONY_HELP = 'com.sony.dtv.smarthelp'
+APP_SONY_INTERNET_BROWSER = 'com.vewd.core.integration.dia'
+APP_SONY_MUSIC = 'com.sony.dtv.osat.music'
+APP_SONY_SCREEN_MIRRORING = 'com.sony.dtv.networkapp.wifidirect'
+APP_SONY_SELECT = 'com.sony.dtv.sonyselect'
+APP_SONY_TIMERS = 'com.sony.dtv.timers'
+APP_SONY_TV = 'com.sony.dtv.tvx'
+APP_SONY_VIDEO = 'com.sony.dtv.osat.video'
 APP_SPORT1 = 'de.sport1.firetv.video'
 APP_SPOTIFY = 'com.spotify.tv.android'
 APP_STEAM_LINK = 'com.valvesoftware.steamlink'
 APP_SYFY = 'com.amazon.webapps.nbc.syfy'
+APP_T2 = 'tv.perception.clients.tv.android'
+APP_TED = 'com.ted.android.tv'
+APP_TUNEIN = 'tunein.player'
 APP_TVHEADEND = 'de.cyberdream.dreamepg.tvh.tv.player'
-APP_TWITCH = 'tv.twitch.android.viewer'
-APP_TWITCH_APP = 'tv.twitch.android.app'
+APP_TWITCH = 'tv.twitch.android.app'
+APP_TWITCH_FIRETV = 'tv.twitch.android.viewer'
+APP_VEVO = 'com.vevo.tv'
 APP_VH1 = 'com.mtvn.vh1android'
+APP_VIMEO = 'com.vimeo.android.videoapp'
 APP_VLC = 'org.videolan.vlc'
+APP_VOYO = 'com.phonegap.voyo'
 APP_VRV = 'com.ellation.vrv'
 APP_WAIPU_TV = 'de.exaring.waipu.firetv.live'
 APP_WATCH_TNT = 'com.turner.tnt.android.networkapp'
 APP_YOUTUBE = 'com.google.android.youtube.tv'
-APP_YOUTUBE_2 = 'com.amazon.firetv.youtube'
+APP_YOUTUBE_FIRETV = 'com.amazon.firetv.youtube'
+APP_YOUTUBE_KIDS = 'com.google.android.youtube.tvkids'
+APP_YOUTUBE_KIDS_FIRETV = 'com.amazon.firetv.youtube.kids'
+APP_YOUTUBE_MUSIC = 'com.google.android.youtube.tvmusic'
+APP_YOUTUBE_TV = 'com.google.android.youtube.tvunplugged'
 APP_ZIGGO_GO_TV = 'com.ziggo.tv'
 APPS = {APP_AE_TV: 'A&E',
+        APP_AMAZON_PRIME_VIDEO: 'Amazon Prime Video',
         APP_AMAZON_VIDEO: 'Amazon Video',
-        APP_AMZ_VIDEO: 'Amz Video',
         APP_APPLE_TV: 'Apple TV',
+        APP_APPLE_TV_FIRETV: 'Apple TV (FireTV)',
         APP_ATV_LAUNCHER: 'Android TV Launcher',
         APP_BELL_FIBE: 'Bell Fibe',
         APP_COMEDY_CENTRAL: 'Comedy Central',
+        APP_DAILYMOTION: 'Dailymotion',
+        APP_DEEZER: 'Deezer',
         APP_DISNEY_PLUS: 'Disney+',
+        APP_DS_PHOTO: 'DS photo',
+        APP_DS_VIDEO: 'DS video',
         APP_ES_FILE_EXPLORER: 'ES File Explorer',
+        APP_FACEBOOK: 'Facebook Watch',
         APP_FAWESOME: 'Fawsome',
         APP_FIREFOX: 'Firefox',
         APP_FIRETV_STORE: 'FireTV Store',
         APP_FOOD_NETWORK_GO: 'Food Network GO',
         APP_FRANCE_TV: 'France TV',
         APP_GOOGLE_CAST: 'Google Cast',
+        APP_GOOGLE_TV_LAUNCHER: 'Google TV Launcher',
+        APP_HAYSTACK_NEWS: 'Haystack News',
         APP_HBO_GO: 'HBO GO',
         APP_HBO_GO_2: 'HBO GO (2)',
         APP_HULU: 'Hulu',
         APP_IMDB_TV: 'IMDb TV',
+        APP_IPTV: 'IPTV',
         APP_IPTV_SMARTERS_PRO: 'IPTV Smarters Pro',
         APP_JELLYFIN_TV: 'Jellyfin',
         APP_KODI: 'Kodi',
+        APP_LIVE_CHANNELS: 'Live Channels',
+        APP_MIJN_RADIO: 'Mijn Radio',
         APP_MOLOTOV: 'Molotov',
+        APP_MX_PLAYER: 'MX Player',
         APP_NETFLIX: 'Netflix',
+        APP_NLZIET: 'NLZIET',
+        APP_NOS: 'NOS',
+        APP_NPO: 'NPO',
         APP_OCS: 'OCS',
         APP_PLAY_GAMES: 'Play Games',
         APP_PLAY_MUSIC: 'Play Music',
         APP_PLAY_STORE: 'Play Store',
-        APP_PLAY_VIDEOS: 'Play Videos',
+        APP_PLAY_VIDEOS: 'Play Movies & TV',
         APP_PLEX: 'Plex',
         APP_PRIME_VIDEO: 'Prime Video',
-        APP_PRIME_VIDEO_2: 'Prime Video (2)',
+        APP_PRIME_VIDEO_FIRETV: 'Prime Video (FireTV)',
+        APP_SETTINGS: 'Settings',
         APP_SMART_YOUTUBE_TV: 'Smart YouTube TV',
+        APP_SONY_ACTION_MENU: 'Action Menu',
+        APP_SONY_ALBUM: 'Album',
+        APP_SONY_BRAVIA_SYNC_MENU: 'Sync Menu',
+        APP_SONY_BRAVIA_TUTORIALS: 'BRAVIA Tutorials',
+        APP_SONY_DISCOVER: 'Discover',
+        APP_SONY_HELP: 'Help',
+        APP_SONY_INTERNET_BROWSER: 'Internet Browser',
+        APP_SONY_MUSIC: 'Music',
+        APP_SONY_SCREEN_MIRRORING: 'Screen mirroring',
+        APP_SONY_SELECT: 'Sony Select',
+        APP_SONY_TIMERS: 'Timers',
+        APP_SONY_TV: 'TV',
+        APP_SONY_VIDEO: 'Video',
         APP_SPORT1: 'Sport 1',
         APP_SPOTIFY: 'Spotify',
         APP_STEAM_LINK: 'Steam Link',
         APP_SYFY: 'Syfy',
-        APP_TVHEADEND: 'DreamPLayer TVHeadend',
+        APP_T2: 'T-2 TV',
+        APP_TED: 'TED',
+        APP_TUNEIN: 'TuneIn Radio',
+        APP_TVHEADEND: 'DreamPlayer TVHeadend',
         APP_TWITCH: 'Twitch',
-        APP_TWITCH_APP: 'Twitch App',
+        APP_TWITCH_FIRETV: 'Twitch (FireTV)',
+        APP_VEVO: 'Vevo',
         APP_VH1: 'VH1',
+        APP_VIMEO: 'Vimeo',
         APP_VLC: 'VLC',
+        APP_VOYO: 'VOYO',
         APP_VRV: 'VRV',
         APP_WAIPU_TV: 'Waipu TV',
         APP_WATCH_TNT: 'Watch TNT',
         APP_YOUTUBE: 'YouTube',
-        APP_YOUTUBE_2: 'YouTube (FireTV)',
+        APP_YOUTUBE_FIRETV: 'YouTube (FireTV)',
+        APP_YOUTUBE_KIDS: 'YouTube Kids',
+        APP_YOUTUBE_KIDS_FIRETV: 'YouTube Kids (FireTV)',
+        APP_YOUTUBE_MUSIC: 'YouTube Music',
+        APP_YOUTUBE_TV: 'YouTube TV',
         APP_ZIGGO_GO_TV: 'Ziggo GO TV'}
 
 
