@@ -37,6 +37,15 @@ class BaseFireTV(BaseTV):  # pylint: disable=too-few-public-methods
     def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None):
         BaseTV.__init__(self, None, host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
 
+    def _fill_in_commands(self):
+        """Fill in commands that are specific to Fire TV devices."""
+        self._cmd_get_properties_lazy_running_apps = constants.CMD_FIRETV_PROPERTIES_LAZY_RUNNING_APPS
+        self._cmd_get_properties_lazy_no_running_apps = constants.CMD_FIRETV_PROPERTIES_LAZY_NO_RUNNING_APPS
+        self._cmd_get_properties_not_lazy_running_apps = constants.CMD_FIRETV_PROPERTIES_NOT_LAZY_RUNNING_APPS
+        self._cmd_get_properties_not_lazy_no_running_apps = constants.CMD_FIRETV_PROPERTIES_NOT_LAZY_NO_RUNNING_APPS
+        self._cmd_current_app = constants.CMD_CURRENT_APP
+        self._cmd_launch_app = constants.CMD_LAUNCH_APP
+
     # ======================================================================= #
     #                                                                         #
     #                          Home Assistant Update                          #
@@ -176,7 +185,7 @@ class BaseFireTV(BaseTV):  # pylint: disable=too-few-public-methods
                     state = constants.STATE_IDLE
 
             # Twitch
-            elif current_app == constants.APP_TWITCH:
+            elif current_app == constants.APP_TWITCH_FIRETV:
                 if wake_lock_size == 2:
                     state = constants.STATE_PAUSED
                 elif media_session_state == 3:
